==> openshift-model-operator-5.2.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/KubeControllerManagerListFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;

public class KubeControllerManagerListFluentImpl<A extends KubeControllerManagerListFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements KubeControllerManagerListFluent<A> {

    private String apiVersion;
    private List<KubeControllerManagerBuilder> items =  new ArrayList<KubeControllerManagerBuilder>();
    private String kind;
    private ListMeta metadata;

    public KubeControllerManagerListFluentImpl() {
    }

    public KubeControllerManagerListFluentImpl(KubeControllerManagerList instance) {
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
    }

    public String getApiVersion() {
        return this.apiVersion;
    }

    public A withApiVersion(String apiVersion) {
        this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion() {
        return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A addToItems(int index,KubeControllerManager item) {
        if (this.items == null) {this.items = new ArrayList<KubeControllerManagerBuilder>();}
        KubeControllerManagerBuilder builder = new KubeControllerManagerBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,KubeControllerManager item) {
        if (this.items == null) {this.items = new ArrayList<KubeControllerManagerBuilder>();}
        KubeControllerManagerBuilder builder = new KubeControllerManagerBuilder(item);
        if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
        if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
         return (A)this;
    }

    public A addToItems(KubeControllerManager... items) {
        if (this.items == null) {this.items = new ArrayList<KubeControllerManagerBuilder>();}
        for (KubeControllerManager item : items) {KubeControllerManagerBuilder builder = new KubeControllerManagerBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<KubeControllerManager> items) {
        if (this.items == null) {this.items = new ArrayList<KubeControllerManagerBuilder>();}
        for (KubeControllerManager item : items) {KubeControllerManagerBuilder builder = new KubeControllerManagerBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(KubeControllerManager... items) {
        for (KubeControllerManager item : items) {KubeControllerManagerBuilder builder = new KubeControllerManagerBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<KubeControllerManager> items) {
        for (KubeControllerManager item : items) {KubeControllerManagerBuilder builder = new KubeControllerManagerBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromItems(Predicate<KubeControllerManagerBuilder> predicate) {
        if (items == null) return (A) this;
        final Iterator<KubeControllerManagerBuilder> each = items.iterator();
        final List visitables = _visitables.get("items");
        while (each.hasNext()) {
          KubeControllerManagerBuilder builder = each.next();
          if (predicate.test(builder)) {
            visitables.remove(builder);
            each.remove();
          }
        }
        return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<KubeControllerManager> getItems() {
        return build(items);
    }

    public List<KubeControllerManager> buildItems() {
        return build(items);
    }

    public KubeControllerManager buildItem(int index) {
        return this.items.get(index).build();
    }

    public KubeControllerManager buildFirstItem() {
        return this.items.get(0).build();
    }

    public KubeControllerManager buildLastItem() {
        return this.items.get(items.size() - 1).build();
    }

    public KubeControllerManager buildMatchingItem(Predicate<KubeControllerManagerBuilder> predicate) {
        for (KubeControllerManagerBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingItem(Predicate<KubeControllerManagerBuilder> predicate) {
        for (KubeControllerManagerBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withItems(List<KubeControllerManager> items) {
        if (this.items != null) { _visitables.get("items").removeAll(this.items);}
        if (items != null) {this.items = new ArrayList<KubeControllerManagerBuilder>(); for (KubeControllerManager item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
    }

    public A withItems(KubeControllerManager... items) {
        if (this.items != null) {this.items.clear();}
        if (items != null) {for (KubeControllerManager item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems() {
        return items != null && !items.isEmpty();
    }

    public KubeControllerManagerListFluent.ItemsNested<A> addNewItem() {
        return new ItemsNestedImpl();
    }

    public KubeControllerManagerListFluent.ItemsNested<A> addNewItemLike(KubeControllerManager item) {
        return new ItemsNestedImpl(-1, item);
    }

    public KubeControllerManagerListFluent.ItemsNested<A> setNewItemLike(int index,KubeControllerManager item) {
        return new ItemsNestedImpl(index, item);
    }

    public KubeControllerManagerListFluent.ItemsNested<A> editItem(int index) {
        if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
        return setNewItemLike(index, buildItem(index));
    }

    public KubeControllerManagerListFluent.ItemsNested<A> editFirstItem() {
        if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
        return setNewItemLike(0, buildItem(0));
    }

    public KubeControllerManagerListFluent.ItemsNested<A> editLastItem() {
        int index = items.size() - 1;
        if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
        return setNewItemLike(index, buildItem(index));
    }

    public KubeControllerManagerListFluent.ItemsNested<A> editMatchingItem(Predicate<KubeControllerManagerBuilder> predicate) {
        int index = -1;
        for (int i=0;i<items.size();i++) { 
        if (predicate.test(items.get(i))) {index = i; break;}
        } 
        if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
        return setNewItemLike(index, buildItem(index));
    }

    public String getKind() {
        return this.kind;
    }

    public A withKind(String kind) {
        this.kind=kind; return (A) this;
    }

    public Boolean hasKind() {
        return this.kind != null;
    }

    public A withNewKind(String arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1) {
        return (A)withKind(new String(arg1));
    }

    public ListMeta getMetadata() {
        return this.metadata;
    }

    public A withMetadata(ListMeta metadata) {
        this.metadata=metadata; return (A) this;
    }

    public Boolean hasMetadata() {
        return this.metadata != null;
    }

    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
        return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        KubeControllerManagerListFluentImpl that = (KubeControllerManagerListFluentImpl) o;
        if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
        if (items != null ? !items.equals(that.items) :that.items != null) return false;
        if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
        if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  super.hashCode());
    }

    public class ItemsNestedImpl<N> extends KubeControllerManagerFluentImpl<KubeControllerManagerListFluent.ItemsNested<N>> implements KubeControllerManagerListFluent.ItemsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final KubeControllerManagerBuilder builder;
        private final int index;

            ItemsNestedImpl(int index,KubeControllerManager item) {
                this.index = index;
                this.builder = new KubeControllerManagerBuilder(this, item);
                        
            }

            ItemsNestedImpl() {
                this.index = -1;
                this.builder = new KubeControllerManagerBuilder(this);
                        
            }

            public N and() {
                return (N) KubeControllerManagerListFluentImpl.this.setToItems(index,builder.build());
            }

            public N endItem() {
                return and();
            }
    }


}

==> openshift-model-operator-5.3.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/KubeControllerManagerListFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;

public class KubeControllerManagerListFluentImpl<A extends KubeControllerManagerListFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements KubeControllerManagerListFluent<A> {

    private String apiVersion;
    private List<KubeControllerManagerBuilder> items =  new ArrayList<KubeControllerManagerBuilder>();
    private String kind;
    private ListMeta metadata;

    public KubeControllerManagerListFluentImpl() {
    }

    public KubeControllerManagerListFluentImpl(KubeControllerManagerList instance) {
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
    }

    public String getApiVersion() {
        return this.apiVersion;
    }

    public A withApiVersion(String apiVersion) {
        this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion() {
        return this.apiVersion != null;
    }

    public A withNewApiVersion(StringBuilder arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(int[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(char[] arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(byte[] arg1,int arg2) {
        return (A)withApiVersion(new String(arg1, arg2));
    }

    public A withNewApiVersion(byte[] arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(char[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(byte[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withApiVersion(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewApiVersion(String arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A addToItems(int index,KubeControllerManager item) {
        if (this.items == null) {this.items = new ArrayList<KubeControllerManagerBuilder>();}
        KubeControllerManagerBuilder builder = new KubeControllerManagerBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,KubeControllerManager item) {
        if (this.items == null) {this.items = new ArrayList<KubeControllerManagerBuilder>();}
        KubeControllerManagerBuilder builder = new KubeControllerManagerBuilder(item);
        if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
        if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
         return (A)this;
    }

    public A addToItems(KubeControllerManager... items) {
        if (this.items == null) {this.items = new ArrayList<KubeControllerManagerBuilder>();}
        for (KubeControllerManager item : items) {KubeControllerManagerBuilder builder = new KubeControllerManagerBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<KubeControllerManager> items) {
        if (this.items == null) {this.items = new ArrayList<KubeControllerManagerBuilder>();}
        for (KubeControllerManager item : items) {KubeControllerManagerBuilder builder = new KubeControllerManagerBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(KubeControllerManager... items) {
        for (KubeControllerManager item : items) {KubeControllerManagerBuilder builder = new KubeControllerManagerBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<KubeControllerManager> items) {
        for (KubeControllerManager item : items) {KubeControllerManagerBuilder builder = new KubeControllerManagerBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromItems(Predicate<KubeControllerManagerBuilder> predicate) {
        if (items == null) return (A) this;
        final Iterator<KubeControllerManagerBuilder> each = items.iterator();
        final List visitables = _visitables.get("items");
        while (each.hasNext()) {
          KubeControllerManagerBuilder builder = each.next();
          if (predicate.test(builder)) {
            visitables.remove(builder);
            each.remove();
          }
        }
        return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<KubeControllerManager> getItems() {
        return build(items);
    }

    public List<KubeControllerManager> buildItems() {
        return build(items);
    }

    public KubeControllerManager buildItem(int index) {
        return this.items.get(index).build();
    }

    public KubeControllerManager buildFirstItem() {
        return this.items.get(0).build();
    }

    public KubeControllerManager buildLastItem() {
        return this.items.get(items.size() - 1).build();
    }

    public KubeControllerManager buildMatchingItem(Predicate<KubeControllerManagerBuilder> predicate) {
        for (KubeControllerManagerBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingItem(Predicate<KubeControllerManagerBuilder> predicate) {
        for (KubeControllerManagerBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withItems(List<KubeControllerManager> items) {
        if (this.items != null) { _visitables.get("items").removeAll(this.items);}
        if (items != null) {this.items = new ArrayList<KubeControllerManagerBuilder>(); for (KubeControllerManager item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
    }

    public A withItems(KubeControllerManager... items) {
        if (this.items != null) {this.items.clear();}
        if (items != null) {for (KubeControllerManager item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems() {
        return items != null && !items.isEmpty();
    }

    public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerListFluent.ItemsNested<A> addNewItem() {
        return new ItemsNestedImpl();
    }

    public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerListFluent.ItemsNested<A> addNewItemLike(KubeControllerManager item) {
        return new ItemsNestedImpl(-1, item);
    }

    public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerListFluent.ItemsNested<A> setNewItemLike(int index,KubeControllerManager item) {
        return new ItemsNestedImpl(index, item);
    }

    public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerListFluent.ItemsNested<A> editItem(int index) {
        if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
        return setNewItemLike(index, buildItem(index));
    }

    public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerListFluent.ItemsNested<A> editFirstItem() {
        if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
        return setNewItemLike(0, buildItem(0));
    }

    public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerListFluent.ItemsNested<A> editLastItem() {
        int index = items.size() - 1;
        if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
        return setNewItemLike(index, buildItem(index));
    }

    public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerListFluent.ItemsNested<A> editMatchingItem(Predicate<KubeControllerManagerBuilder> predicate) {
        int index = -1;
        for (int i=0;i<items.size();i++) { 
        if (predicate.test(items.get(i))) {index = i; break;}
        } 
        if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
        return setNewItemLike(index, buildItem(index));
    }

    public String getKind() {
        return this.kind;
    }

    public A withKind(String kind) {
        this.kind=kind; return (A) this;
    }

    public Boolean hasKind() {
        return this.kind != null;
    }

    public A withNewKind(StringBuilder arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(int[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(char[] arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(byte[] arg1,int arg2) {
        return (A)withKind(new String(arg1, arg2));
    }

    public A withNewKind(byte[] arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(char[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(byte[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withKind(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewKind(String arg1) {
        return (A)withKind(new String(arg1));
    }

    public ListMeta getMetadata() {
        return this.metadata;
    }

    public A withMetadata(ListMeta metadata) {
        this.metadata=metadata; return (A) this;
    }

    public Boolean hasMetadata() {
        return this.metadata != null;
    }

    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
        return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        KubeControllerManagerListFluentImpl that = (KubeControllerManagerListFluentImpl) o;
        if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
        if (items != null ? !items.equals(that.items) :that.items != null) return false;
        if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
        if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  super.hashCode());
    }

    public class ItemsNestedImpl<N> extends KubeControllerManagerFluentImpl<io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerListFluent.ItemsNested<N>> implements io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerListFluent.ItemsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final KubeControllerManagerBuilder builder;
        private final int index;

            ItemsNestedImpl(int index,KubeControllerManager item) {
                this.index = index;
                this.builder = new KubeControllerManagerBuilder(this, item);
                        
            }

            ItemsNestedImpl() {
                this.index = -1;
                this.builder = new KubeControllerManagerBuilder(this);
                        
            }

            public N and() {
                return (N) KubeControllerManagerListFluentImpl.this.setToItems(index,builder.build());
            }

            public N endItem() {
                return and();
            }
    }


}
